VERSION 5.00
Begin VB.Form frmBinaryArb 
   Caption         =   "Arbitrary Waveform - Damped Sine"
   ClientHeight    =   2400
   ClientLeft      =   75
   ClientTop       =   360
   ClientWidth     =   3495
   LinkTopic       =   "Form1"
   ScaleHeight     =   2400
   ScaleWidth      =   3495
   StartUpPosition =   3  'Windows Default
   Begin VB.TextBox txtIO 
      Height          =   375
      Left            =   1800
      TabIndex        =   3
      Text            =   "GPIB0::10::INSTR"
      Top             =   480
      Width           =   1575
   End
   Begin VB.TextBox txtError 
      Height          =   975
      Left            =   120
      MultiLine       =   -1  'True
      TabIndex        =   1
      Text            =   "frmBinaryArb.frx":0000
      Top             =   1320
      Width           =   3255
   End
   Begin VB.CommandButton cmdBinaryArb 
      Caption         =   "Setup Instrument"
      Height          =   735
      Left            =   120
      TabIndex        =   0
      Top             =   120
      Width           =   1575
   End
   Begin VB.Label lblIO 
      Caption         =   "IO Address"
      Height          =   255
      Left            =   1800
      TabIndex        =   4
      Top             =   240
      Width           =   1575
   End
   Begin VB.Label lblError 
      Caption         =   "Messages"
      Height          =   375
      Left            =   120
      TabIndex        =   2
      Top             =   1080
      Width           =   2295
   End
End
Attribute VB_Name = "frmBinaryArb"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
Option Explicit

' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
'    Copyright  2002 Agilent Technologies Inc. All rights
'    reserved.
'
' You have a royalty-free right to use, modify, reproduce and distribute
' the Sample Application Files (and/or any modified version) in any way
' you find useful, provided that you agree that Agilent has no
' warranty,  obligations or liability for any Sample Application Files.
'
' Agilent Technologies provides programming examples for illustration only,
' This sample program assumes that you are familiar with the programming
' language being demonstrated and the tools used to create and debug
' procedures. Agilent support engineers can help explain the
' functionality of Agilent software components and associated
' commands, but they will not modify these samples to provide added
' functionality or construct procedures to meet your specific needs.
' """"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

Private Sub cmdBinaryArb_Click()

    ' This program is an example program intended for use with
    ' Microsoft Visual Basic 6.0 and the Agilent IVI COM objects.
    '
    ' To use the IO object in another Visual Basic project, set the
    ' reference to include the library in the Project/References menu:
    ' "IVI Agilent33220A (Agilent Technologies) 1.0 Type Library"
    '
    ' Then use a statement such as "Dim Fgen As Agilent33220"
    ' to create the formatted I/O reference and use
    ' "Set Fgen = New Agilent33220" to create the actual object.
    
    Dim Fgen As Agilent33220
    Set Fgen = New Agilent33220
    
    Fgen.Initialize txtIO.Text, True, True
     
    Dim Waveform() As Integer
    Dim I As Integer
    Dim Ncycles As Integer
    Dim Damp_factor As Single
    Dim Value As String
    Dim pi As Single
    ReDim Waveform(1 To 16000)

    On Error GoTo MyError

    ' This program shows how to down load an arbitrary waveform
    ' using binary data.  The program generates a damped sine
    ' wave using 16,000 points.

    With Fgen

        .System.TimeoutMilliseconds = 40000                 ' Set timeout to 40 seconds for long download strings
        .Utility.Reset                                      ' Reset the function generator
        .Status.Clear
        
        .Output.Frequency = 5000                            ' Output frequency is 5 kHz
        .Output.Load = 50                                   ' Output termination is 50 Ohms
        .Output.Voltage.Amplitude = 5                       ' Output amplitude is 5 Vpp

    End With

    txtError.Text = ""
    txtError.SelText = "Computing Waveform..." & vbCrLf

    Ncycles = 10                                            ' Define number of sinewave cycles
    Damp_factor = -5                                        ' Define damping factor
    pi = 3.14159                                            ' Define pi

    '
    ' Calculate data points
    '

    For I = 1 To 16000
        If I < 14000 Then
            Waveform(I) = (Sin(2 * pi * Ncycles * I / 14000) * 2047)
            Waveform(I) = Waveform(I) * Exp(Damp_factor * I / 14000)
        Else
            Waveform(I) = 0
        End If
    Next I

    ' Download data points to volatile memory from array

    txtError.SelText = "Downloading Arb..." & vbCrLf
    With Fgen
        .ArbitraryWaveform.SetDataDAC Waveform
        .System.IO.WriteString "*OPC?", True
        Value = .System.IO.ReadString
    End With
    txtError.SelText = "Download Complete" & vbCrLf

    With Fgen

        .ArbitraryWaveform.CopyData "DAMP_SINE"             ' Copy arb to non-volatile memory
        .ArbitraryWaveform.User = "DAMP_SINE"               ' Select the active arb waveform
        .Output.Function = Agilent33220OutputFunctionUser                 ' Output the selected arb waveform
        .Output.State = True                                ' Enable output

    End With

    Exit Sub

MyError:

    txtError = Err.Description & vbCrLf
    Resume Next

End Sub

