VERSION 5.00
Begin VB.Form frmBinaryArb 
   Caption         =   "Arbitrary Waveform - Damped Sine"
   ClientHeight    =   2670
   ClientLeft      =   75
   ClientTop       =   360
   ClientWidth     =   4035
   LinkTopic       =   "Form1"
   ScaleHeight     =   2670
   ScaleWidth      =   4035
   StartUpPosition =   3  'Windows Default
   Begin VB.TextBox txtAddress 
      BeginProperty DataFormat 
         Type            =   1
         Format          =   "0"
         HaveTrueFalseNull=   0
         FirstDayOfWeek  =   0
         FirstWeekOfYear =   0
         LCID            =   1033
         SubFormatType   =   1
      EndProperty
      Height          =   375
      Left            =   1920
      TabIndex        =   3
      Text            =   "10"
      Top             =   480
      Width           =   1455
   End
   Begin VB.TextBox txtError 
      Height          =   975
      Left            =   120
      MultiLine       =   -1  'True
      TabIndex        =   1
      Text            =   "frmBinaryArb.frx":0000
      Top             =   1320
      Width           =   3255
   End
   Begin VB.CommandButton cmdBinaryArb 
      Caption         =   "Setup Instrument"
      Height          =   735
      Left            =   120
      TabIndex        =   0
      Top             =   120
      Width           =   1575
   End
   Begin VB.Label lblGPIB 
      Caption         =   "GPIB Address:"
      Height          =   255
      Left            =   1920
      TabIndex        =   4
      Top             =   240
      Width           =   1455
   End
   Begin VB.Label lblError 
      Caption         =   "Messages"
      Height          =   375
      Left            =   120
      TabIndex        =   2
      Top             =   1080
      Width           =   2295
   End
End
Attribute VB_Name = "frmBinaryArb"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
Option Explicit

' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
'    Copyright  2002 Agilent Technologies Inc. All rights
'    reserved.
'
' You have a royalty-free right to use, modify, reproduce and distribute
' the Sample Application Files (and/or any modified version) in any way
' you find useful, provided that you agree that Agilent has no
' warranty,  obligations or liability for any Sample Application Files.
'
' Agilent Technologies provides programming examples for illustration only,
' This sample program assumes that you are familiar with the programming
' language being demonstrated and the tools used to create and debug
' procedures. Agilent support engineers can help explain the
' functionality of Agilent software components and associated
' commands, but they will not modify these samples to provide added
' functionality or construct procedures to meet your specific needs.
' """"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

Private Sub cmdBinaryArb_Click()

    Dim Waveform() As Integer
    Dim I As Integer
    Dim Ncycles As Integer
    Dim Damp_factor As Single
    Dim value As String
    Dim pi As Single
    ReDim Waveform(1 To 16000)
    Dim SCPIcmd As String
    Dim replyString As String * 256
    Dim Instrument As Long
    Dim Length As Long
    
    
    ' This example program is adapted for Microsoft Visual Basic 6.0
    ' and uses the NI-488 I/O Library.  The files Niglobal.bas and
    ' VBIB-32.bas must be loaded in the project.

    On Error GoTo MyError

    ' This program shows how to down load an arbitrary waveform
    ' using binary data.  The program generates a damped sine
    ' wave using 16,000 points.
    
    Instrument = CInt(txtAddress)
    Call SendIFC(0)
    If (ibsta And EERR) Then
        MsgBox "Unable to communicate with function/arb generator."
        End
    End If

            SCPIcmd = "*RST"                                     ' Reset the function generator
            Call Send(0, Instrument, SCPIcmd, NLend)
            SCPIcmd = "FORMat:BORDer SWAP"                       ' Swap data bytes (send LSB first)
            Call Send(0, Instrument, SCPIcmd, NLend)
            SCPIcmd = "FREQuency 5000"                           ' Output frequency is 5 kHz
            Call Send(0, Instrument, SCPIcmd, NLend)
            SCPIcmd = "OUTPut:LOAD 50"                           ' Output termination is 50 Ohms
            Call Send(0, Instrument, SCPIcmd, NLend)
            SCPIcmd = "VOLTage 5"                                ' Output amplitude is 5 Vpp
            Call Send(0, Instrument, SCPIcmd, NLend)

    txtError.Text = ""
    txtError.SelText = "Computing Waveform..." & vbCrLf

    Ncycles = 10                                           ' Define number of sinewave cycles
    Damp_factor = -5                                       ' Define damping factor
    pi = 3.14159                                           ' Define pi

    '
    ' Calculate data points
    '

    For I = 1 To 16000
        If I < 14000 Then
            Waveform(I) = (Sin(2 * pi * Ncycles * I / 14000) * 2047)
            Waveform(I) = Waveform(I) * Exp(Damp_factor * I / 14000)
        Else
            Waveform(I) = 0
        End If
    Next I
    
    ' Download data points to volatile memory from array

    txtError.SelText = "Downloading Arb..." & vbCrLf
    
            SCPIcmd = "Data:Dac Volatile,#532000"
            Call Send(0, Instrument, SCPIcmd, NULLend)
            Call ibwrt32(0, Waveform(1), 32000)
        
            SCPIcmd = ";*OPC?"
            Call Send(0, Instrument, SCPIcmd, NLend)
            Call Receive(0, Instrument, replyString, NLend)
            value = Left$(replyString, ibcntl - 1)

    txtError.SelText = "Download Complete" & vbCrLf

            SCPIcmd = "DATA:COPY DAMP_SINE, VOLATILE"            ' Copy arb to non-volatile memory
            Call Send(0, Instrument, SCPIcmd, NLend)
            SCPIcmd = "FUNCtion:USER DAMP_SINE"                  ' Select the active arb waveform
            Call Send(0, Instrument, SCPIcmd, NLend)
            SCPIcmd = "FUNCtion:SHAPe USER"                      ' Output the selected arb waveform
            Call Send(0, Instrument, SCPIcmd, NLend)
            SCPIcmd = "OUTPut ON"                                ' Enable output
            Call Send(0, Instrument, SCPIcmd, NLend)

    Call ibonl(Instrument, 0)

    Exit Sub

MyError:

    txtError = Err.Description & vbCrLf
    Resume Next
    
End Sub

