VERSION 5.00
Begin VB.Form frmBinaryArb 
   Caption         =   "Arbitrary Waveform - Damped Sine"
   ClientHeight    =   2670
   ClientLeft      =   75
   ClientTop       =   360
   ClientWidth     =   4035
   LinkTopic       =   "Form1"
   ScaleHeight     =   2670
   ScaleWidth      =   4035
   StartUpPosition =   3  'Windows Default
   Begin VB.TextBox txtAddress 
      Height          =   375
      Left            =   1920
      TabIndex        =   3
      Text            =   "GPIB::10::INSTR"
      Top             =   480
      Width           =   1455
   End
   Begin VB.TextBox txtError 
      Height          =   975
      Left            =   120
      MultiLine       =   -1  'True
      TabIndex        =   1
      Text            =   "frmBinaryArb.frx":0000
      Top             =   1320
      Width           =   3255
   End
   Begin VB.CommandButton cmdBinaryArb 
      Caption         =   "Setup Instrument"
      Height          =   735
      Left            =   120
      TabIndex        =   0
      Top             =   120
      Width           =   1575
   End
   Begin VB.Label lblGPIB 
      Caption         =   "GPIB Address:"
      Height          =   255
      Left            =   1920
      TabIndex        =   4
      Top             =   240
      Width           =   1455
   End
   Begin VB.Label lblError 
      Caption         =   "Messages"
      Height          =   375
      Left            =   120
      TabIndex        =   2
      Top             =   1080
      Width           =   2295
   End
End
Attribute VB_Name = "frmBinaryArb"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = False
Attribute VB_PredeclaredId = True
Attribute VB_Exposed = False
Option Explicit

' """""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""
'    Copyright  2002 Agilent Technologies Inc. All rights
'    reserved.
'
' You have a royalty-free right to use, modify, reproduce and distribute
' the Sample Application Files (and/or any modified version) in any way
' you find useful, provided that you agree that Agilent has no
' warranty,  obligations or liability for any Sample Application Files.
'
' Agilent Technologies provides programming examples for illustration only,
' This sample program assumes that you are familiar with the programming
' language being demonstrated and the tools used to create and debug
' procedures. Agilent support engineers can help explain the
' functionality of Agilent software components and associated
' commands, but they will not modify these samples to provide added
' functionality or construct procedures to meet your specific needs.
' """"""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""""

Private Sub cmdBinaryArb_Click()

    Dim address As String
    Dim InstOutput As Long
    Dim vi As Long
    Dim vi2 As Long
    Dim Waveform() As Integer
    Dim I As Integer
    Dim Ncycles As Integer
    Dim Damp_factor As Single
    Dim pi As Single
    ReDim Waveform(1 To 16000)
    Dim reply As Integer

    address = txtAddress.Text                                                ' Instrument GPIB address
    InstOutput = ag33250a_init(address, 1, 0, vi)                            ' This funcion initializes the instrument

    ' This program is an example adapted for Microsoft
    ' Visual Basic 6.0 and requires the VISA revision 2.0 and the
    ' Agilent Technologies 33250A instrument driver installed.

    On Error GoTo MyError

    ' This program shows how to down load an arbitrary waveform
    ' using binary data.  The program generates a damped sine
    ' wave using 16,000 points.

    InstOutput = ag33250a_reset(vi)                                          ' Reset the function generator
    InstOutput = ag33250a_dcl(vi)                                            ' Clear errors and status registers
    InstOutput = ag33250a_formBord(vi, ag33250a_ARB_WAV_FORM_BOR_SWAPPED)    ' Swap data bytes (send LSB first)

    InstOutput = ag33250a_freq(vi, 5000)                                     ' Output frequency is 5 kHz
    InstOutput = ag33250a_outpLoad(vi, ag33250a_OUTPUT_LOAD_50)              ' Output termination is 50 Ohms
    InstOutput = ag33250a_volt(vi, 5)                                        ' Output amplitude is 5 Vpp

    txtError.Text = ""
    txtError.SelText = "Computing Waveform..." & vbCrLf

    Ncycles = 10                                                             ' Define number of sinewave cycles
    Damp_factor = -5                                                         ' Define damping factor
    pi = 3.14159                                                             ' Define pi

    '
    ' Calculate data points
    '


    For I = 1 To 16000
        If I < 14000 Then
            Waveform(I) = (Sin(2 * pi * Ncycles * I / 14000) * 2047)
            Waveform(I) = Waveform(I) * Exp(Damp_factor * I / 14000)
        Else
            Waveform(I) = 0
        End If
    Next I

    ' Download data points to volatile memory from array

    txtError.SelText = "Downloading Arb..." & vbCrLf

    InstOutput = ag33250a_dataDacVolatile(vi, 16000, Waveform(1))
    InstOutput = ag33250a_opc_Q(vi, reply)

    txtError.SelText = "Download Complete" & vbCrLf

    InstOutput = ag33250a_dataCopy(vi, "DAMP_SINE")                          ' Copy arb to non-volatile memory
    InstOutput = ag33250a_funcUserName(vi, "DAMP_SINE")                     ' Select the active arb waveform
    InstOutput = ag33250a_funcShap(vi, ag33250a_OUTPUT_FUNC_USER)            ' Output the selected arb waveform

    InstOutput = ag33250a_outpSetup(vi, ag33250a_OUTPUT_SETUP_ON)            ' Enable output

    InstOutput = ag33250a_close(vi)

    Exit Sub

MyError:

    txtError = Err.Description & vbCrLf
    Resume Next

End Sub

