' Copyright (C) 2000-2003 Agilent Technologies
' Driver for 33250A, 80 MHz Function / Arbitrary Waveform Generator
' Driver for 33220A, 40 MHz Function / Arbitrary Waveform Generator
' Driver Version: A.00.03

'------------------------------------------------------------------------------
' Global Constants

'------------------------------------------------------------------------------

'  Returned error status values
'  Agilent Common Error numbers start at BFFC0D00

Global Const ag33250a_INSTR_ERROR_NOT_VXI = &HBFFC0D00
' D01 unused
Global Const ag33250a_INSTR_ERROR_NULL_PTR = &HBFFC0D02
Global Const ag33250a_INSTR_ERROR_RESET_FAILED = &HBFFC0D03
Global Const ag33250a_INSTR_ERROR_UNEXPECTED = &HBFFC0D04
Global Const ag33250a_INSTR_ERROR_INV_SESSION = &HBFFC0D05
Global Const ag33250a_INSTR_ERROR_LOOKUP = &HBFFC0D06
Global Const ag33250a_INSTR_ERROR_DETECTED = &HBFFC0D07

' Parameter errors not in VPP 3.4
Global Const ag33250a_INSTR_ERROR_PARAMETER9 = &HBFFC0D20
Global Const ag33250a_INSTR_ERROR_PARAMETER10 = &HBFFC0D21
Global Const ag33250a_INSTR_ERROR_PARAMETER11 = &HBFFC0D22
Global Const ag33250a_INSTR_ERROR_PARAMETER12 = &HBFFC0D23
Global Const ag33250a_INSTR_ERROR_PARAMETER13 = &HBFFC0D24
Global Const ag33250a_INSTR_ERROR_PARAMETER14 = &HBFFC0D25
Global Const ag33250a_INSTR_ERROR_PARAMETER15 = &HBFFC0D26
Global Const ag33250a_INSTR_ERROR_PARAMETER16 = &HBFFC0D27
Global Const ag33250a_INSTR_ERROR_PARAMETER17 = &HBFFC0D28
Global Const ag33250a_INSTR_ERROR_PARAMETER18 = &HBFFC0D29

' Used by Status System Functions
Global Const ag33250a_USER_ERROR_HANDLER = -1

Global Const ag33250a_ESR_OPC = 601
Global Const ag33250a_ESR_QUERY_ERROR = 603
Global Const ag33250a_ESR_DEVICE_DEPENDENT_ERROR = 604
Global Const ag33250a_ESR_EXECUTION_ERROR = 605
Global Const ag33250a_ESR_COMMAND_ERROR = 606

' Used by Function ag33250a_timeOut
Global Const ag33250a_TIMEOUT_MAX = 2147483647
Global Const ag33250a_TIMEOUT_MIN = 0&


'------------------------------------------------------------------------------
' Function Declarations
'------------------------------------------------------------------------------

' required plug and play functions from VPP-3.1
Declare Function ag33250a_init Lib "ag33250a_32.dll" (ByVal InstrDesc As String, ByVal id_query As Integer, ByVal do_reset As Integer, vi As Long) As Long

Declare Function ag33250a_close Lib "ag33250a_32.dll" (ByVal vi As Long) As Long

Declare Function ag33250a_reset Lib "ag33250a_32.dll" (ByVal vi As Long) As Long

Declare Function ag33250a_self_test Lib "ag33250a_32.dll" (ByVal vi As Long, test_result As Integer, ByVal test_message As String) As Long

Declare Function ag33250a_error_query Lib "ag33250a_32.dll" (ByVal vi As Long, error_number As Long, ByVal error_message As String) As Long

Declare Function ag33250a_error_message Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal error_number As Long, ByVal message As String) As Long

Declare Function ag33250a_revision_query Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal driver_rev As String, ByVal instr_rev As String) As Long

' Agilent other standard functions

Declare Function ag33250a_dcl Lib "ag33250a_32.dll" (ByVal vi As Long) As Long

Declare Function ag33250a_opc Lib "ag33250a_32.dll" (ByVal vi As Long) As Long

Declare Function ag33250a_opc_Q Lib "ag33250a_32.dll" (ByVal vi As Long, opc As Integer) As Long

Declare Function ag33250a_readStatusByte_Q Lib "ag33250a_32.dll" (ByVal vi As Long, statusByte As Integer) As Long

Declare Function ag33250a_timeOut Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal timeOut As Long) As Long

Declare Function ag33250a_timeOut_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pTimeOut As Long) As Long

Declare Function ag33250a_trg Lib "ag33250a_32.dll" (ByVal vi As Long) As Long

Declare Function ag33250a_wai Lib "ag33250a_32.dll" (ByVal vi As Long) As Long

Declare Function ag33250a_cmd Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal cmdStr As String) As Long

Declare Function ag33250a_cmdInt Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal cmdStr As String, ByVal sendInt As Long) As Long

Declare Function ag33250a_cmdReal Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal cmdStr As String, ByVal sendReal As Double) As Long

Declare Function ag33250a_cmdString Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal cmdStr As String, ByVal sendStr As String) As Long

Declare Function ag33250a_cmdInt16_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal cmdStr As String, result As Integer) As Long

Declare Function ag33250a_cmdInt32_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal cmdStr As String, result As Long) As Long

Declare Function ag33250a_cmdReal32_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal cmdStr As String, result As Single) As Long

Declare Function ag33250a_cmdReal64_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal cmdStr As String, result As Double) As Long

Declare Function ag33250a_cmdString_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal cmdStr As String, ByVal arrSize As Long, ByVal result As String) As Long

'------------------------------------------------------------------------------
' Global Constants

'------------------------------------------------------------------------------

' Used by Function ag33250a_amDept
Global Const ag33250a_AMP_MOD_MAX = 120#
Global Const ag33250a_AMP_MOD_MIN = 0#

' Used by Function ag33250a_amDept_Q
Global Const ag33250a_CURRENT_RANGE = 0
Global Const ag33250a_MIN_RANGE = 1
Global Const ag33250a_MAX_RANGE = 2

' Used by Function ag33250a_amIntFreq
Global Const ag33250a_AMP_MOD_FREQ_MAX = 20000#
Global Const ag33250a_AMP_MOD_FREQ_MIN = 0.002

' Used by Function ag33250a_amIntFreq_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_amIntFunc
Global Const ag33250a_AMP_INT_FUNC_SIN = 0
Global Const ag33250a_AMP_INT_FUNC_SQU = 1
Global Const ag33250a_AMP_INT_FUNC_RAMP = 2
Global Const ag33250a_AMP_INT_FUNC_NRAMP = 3
Global Const ag33250a_AMP_INT_FUNC_TRI = 4
Global Const ag33250a_AMP_INT_FUNC_NOIS = 5
Global Const ag33250a_AMP_INT_FUNC_USER = 6

' Used by Function ag33250a_amIntFunc_Q
'    ag33250a_AMP_INT_FUNC_SIN
'    ag33250a_AMP_INT_FUNC_SQU
'    ag33250a_AMP_INT_FUNC_TRI
'    ag33250a_AMP_INT_FUNC_RAMP
'    ag33250a_AMP_INT_FUNC_NOIS
'    ag33250a_AMP_INT_FUNC_USER

' Used by Function ag33250a_amSour
Global Const ag33250a_AMP_MOD_SOUR_INT = 0
Global Const ag33250a_AMP_MOD_SOUR_EXT = 1

' Used by Function ag33250a_amSour_Q
'    ag33250a_AMP_MOD_SOUR_INT
'    ag33250a_AMP_MOD_SOUR_EXT

' Used by Function ag33250a_amState
Global Const ag33250a_AMP_STAT_OFF = 0
Global Const ag33250a_AMP_STAT_ON = 1

' Used by Function ag33250a_appl
Global Const ag33250a_APPL_SIN = 0
Global Const ag33250a_APPL_SQU = 1
Global Const ag33250a_APPL_RAMP = 2
Global Const ag33250a_APPL_PULS = 3
Global Const ag33250a_APPL_NOIS = 4
Global Const ag33250a_APPL_DC = 5
Global Const ag33250a_APPL_USER = 6
Global Const ag33250a_FREQ_MAX = 80000000#
Global Const ag33250a_FREQ_MIN = 0.000001
Global Const ag33250a_AMPL_MAX = 10#
Global Const ag33250a_AMPL_MIN = 0.001
Global Const ag33250a_OFFS_MAX = 5
Global Const ag33250a_OFFS_MIN = -5

' Used by Function ag33250a_bmIntRate
Global Const ag33250a_BM_MOD_RATE_MAX = 1000000#
Global Const ag33250a_BM_MOD_RATE_MIN = 0.002

' Used by Function ag33250a_bmIntRate_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_bmNcyc
Global Const ag33250a_BM_MOD_NCYC_MAX = 1000000
Global Const ag33250a_BM_MOD_NCYC_MIN = 1

' Used by Function ag33250a_bmNcyc_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_bmPhas
Global Const ag33250a_BM_MOD_PHAS_MAX = 360
Global Const ag33250a_BM_MOD_PHAS_MIN = -360

' Used by Function ag33250a_bmPhas_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_bmSour
Global Const ag33250a_BM_MOD_SOUR_TRIG = 0
Global Const ag33250a_BM_MOD_SOUR_GAT = 1

' Used by Function ag33250a_bmSour_Q
'    ag33250a_BM_MOD_SOUR_TRIG
'    ag33250a_BM_MOD_SOUR_GAT

' Used by Function ag33250a_bmStat
Global Const ag33250a_BM_STAT_OFF = 0
Global Const ag33250a_BM_STAT_ON = 1

' Used by Function ag33250a_calSet
Global Const ag33250a_CAL_STEP_MAX = 115
Global Const ag33250a_CAL_STEP_MIN = 0

' Used by Function ag33250a_dataDacVolatile
Global Const ag33250a_NOOFPOINTS_MAX = 65536
Global Const ag33250a_NOOFPOINTS_MIN = 1

' Used by Function ag33250a_dataVolatile
'    ag33250a_NOOFPOINTS_MAX
'    ag33250a_NOOFPOINTS_MIN

' Used by Function ag33250a_disp
Global Const ag33250a_DISP_STAT_OFF = 0
Global Const ag33250a_DISP_STAT_ON = 1

' Used by Function ag33250a_fmDev
Global Const ag33250a_FREQ_MOD_DEV_MAX = 40050000#
Global Const ag33250a_FREQ_MOD_DEV_MIN = 5

' Used by Function ag33250a_fmDev_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_fmIntFreq
Global Const ag33250a_FREQ_MOD_FREQ_MAX = 20000#
Global Const ag33250a_FREQ_MOD_FREQ_MIN = 0.002

' Used by Function ag33250a_fmIntFreq_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_fmIntFunc
Global Const ag33250a_FREQ_INT_FUNC_SIN = 0
Global Const ag33250a_FREQ_INT_FUNC_SQU = 1
Global Const ag33250a_FREQ_INT_FUNC_RAMP = 2
Global Const ag33250a_FREQ_INT_FUNC_NRAMP = 3
Global Const ag33250a_FREQ_INT_FUNC_TRI = 4
Global Const ag33250a_FREQ_INT_FUNC_NOIS = 5
Global Const ag33250a_FREQ_INT_FUNC_USER = 6

' Used by Function ag33250a_fmIntFunc_Q
'    ag33250a_FREQ_INT_FUNC_SIN
'    ag33250a_FREQ_INT_FUNC_SQU
'    ag33250a_FREQ_INT_FUNC_TRI
'    ag33250a_FREQ_INT_FUNC_RAMP
'    ag33250a_FREQ_INT_FUNC_NOIS
'    ag33250a_FREQ_INT_FUNC_USER

' Used by Function ag33250a_fmStat
Global Const ag33250a_FREQ_STAT_OFF = 0
Global Const ag33250a_FREQ_STAT_ON = 1

' Used by Function ag33250a_formBord
Global Const ag33250a_ARB_WAV_FORM_BOR_NORMAL = 0
Global Const ag33250a_ARB_WAV_FORM_BOR_SWAPPED = 1

' Used by Function ag33250a_formBord_Q
'    ag33250a_ARB_WAV_FORM_BOR_NORMAL
'    ag33250a_ARB_WAV_FORM_BOR_SWAPPED

' Used by Function ag33250a_freq
Global Const ag33250a_OUTPUT_FREQ_MAX = 80000000#
Global Const ag33250a_OUTPUT_FREQ_MIN = 0.000001

' Used by Function ag33250a_freqStar
Global Const ag33250a_SWEEP_FREQ_START_MAX = 80000000#
Global Const ag33250a_SWEEP_FREQ_START_MIN = 0.000001

' Used by Function ag33250a_freqStar_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_freqStop
Global Const ag33250a_SWEEP_FREQ_STOP_MAX = 80000000#
Global Const ag33250a_SWEEP_FREQ_STOP_MIN = 0.000001

' Used by Function ag33250a_freqStop_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_freq_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_fskFreq
Global Const ag33250a_FSK_FREQ_MAX = 80000000#
Global Const ag33250a_FSK_FREQ_MIN = 0.000001

' Used by Function ag33250a_fskFreq_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_fskIntRate
Global Const ag33250a_FSK_RATE_MAX = 1000000#
Global Const ag33250a_FSK_RATE_MIN = 0.002

' Used by Function ag33250a_fskIntRate_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_fskSour
Global Const ag33250a_FSK_SOUR_INT = 0
Global Const ag33250a_FSK_SOUR_EXT = 1

' Used by Function ag33250a_fskSour_Q
'    ag33250a_FSK_SOUR_INT
'    ag33250a_FSK_SOUR_EXT

' Used by Function ag33250a_fskStat
Global Const ag33250a_FSK_STAT_OFF = 0
Global Const ag33250a_FSK_STAT_ON = 1

' Used by Function ag33250a_funcShap
Global Const ag33250a_OUTPUT_FUNC_SIN = 0
Global Const ag33250a_OUTPUT_FUNC_SQU = 1
Global Const ag33250a_OUTPUT_FUNC_RAMP = 2
Global Const ag33250a_OUTPUT_FUNC_PULS = 3
Global Const ag33250a_OUTPUT_FUNC_NOIS = 4
Global Const ag33250a_OUTPUT_FUNC_DC = 5
Global Const ag33250a_OUTPUT_FUNC_USER = 6

' Used by Function ag33250a_funcShap_Q
'    ag33250a_OUTPUT_FUNC_SIN
'    ag33250a_OUTPUT_FUNC_SQU
'    ag33250a_OUTPUT_FUNC_RAMP
'    ag33250a_OUTPUT_FUNC_PULS
'    ag33250a_OUTPUT_FUNC_NOIS
'    ag33250a_OUTPUT_FUNC_DC
'    ag33250a_OUTPUT_FUNC_USER

' Used by Function ag33250a_funcUser
Global Const ag33250a_ARB_FUNC_USER_EXP_RISE = 0
Global Const ag33250a_ARB_FUNC_USER_EXP_FALL = 1
Global Const ag33250a_ARB_FUNC_USER_NEG_RAMP = 2
Global Const ag33250a_ARB_FUNC_USER_SINC = 3
Global Const ag33250a_ARB_FUNC_USER_CARDIAC = 4
Global Const ag33250a_ARB_FUNC_USER_VOLATILE = 5

' Used by Function ag33250a_funcUser_Q
'    ag33250a_ARB_FUNC_USER_EXP_RISE
'    ag33250a_ARB_FUNC_USER_EXP_FALL
'    ag33250a_ARB_FUNC_USER_NEG_RAMP
'    ag33250a_ARB_FUNC_USER_SINC
'    ag33250a_ARB_FUNC_USER_CARDIAC
'    ag33250a_ARB_FUNC_USER_VOLATILE

' Used by Function ag33250a_memStatDel
Global Const ag33250a_MEMDEL_STATE_MAX = 4
Global Const ag33250a_MEMDEL_STATE_MIN = 0

' Used by Function ag33250a_outpSetup
Global Const ag33250a_OUTPUT_SETUP_OFF = 0
Global Const ag33250a_OUTPUT_SETUP_ON = 1

' Used by Function ag33250a_outpLoad
Global Const ag33250a_OUTPUT_LOAD_50 = 0
Global Const ag33250a_OUTPUT_LOAD_INF = 1
Global Const ag33250a_OUTPUT_LOAD_MIN = 2
Global Const ag33250a_OUTPUT_LOAD_MAX = 3

' Used by Function ag33250a_outpLoad_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_outpSync
Global Const ag33250a_OUTPUT_SYNC_OFF = 0
Global Const ag33250a_OUTPUT_SYNC_ON = 1

' Used by Function ag33250a_pulsDcyc
Global Const ag33250a_OUTPUT_PULS_DCYC_MAX = 80
Global Const ag33250a_OUTPUT_PULS_DCYC_MIN = 20

' Used by Function ag33250a_pulsDcyc_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_pulsePeriod
Global Const ag33250a_PULSE_PER_MAX = 2000
Global Const ag33250a_PULSE_PER_MIN = 0.00000002

' Used by Function ag33250a_pulsePeriod_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_pulseWidth
Global Const ag33250a_PULSE_WIDTH_MAX = 200
Global Const ag33250a_PULSE_WIDTH_MIN = 0.000000008

' Used by Function ag33250a_pulseWidth_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_pulseTrans
Global Const ag33250a_PULSE_TRANS_MAX = 0.001
Global Const ag33250a_PULSE_TRANS_MIN = 0.000000005

' Used by Function ag33250a_pulseTrans_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_rampSymm
Global Const ag33250a_OUTPUT_RAMP_SYMM__MAX = 100
Global Const ag33250a_OUTPUT_RAMP_SYMM__MIN = 0

' Used by Function ag33250a_rampSymm_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_rcl
Global Const ag33250a_RECALL_MAX = 4
Global Const ag33250a_RECALL_MIN = 0

' Used by Function ag33250a_sav
Global Const ag33250a_SAVE_MAX = 4
Global Const ag33250a_SAVE_MIN = 0

' Used by Function ag33250a_sweSpac
Global Const ag33250a_SWEEP_SPAC_LIN = 0
Global Const ag33250a_SWEEP_SPAC_LOG = 2

' Used by Function ag33250a_sweSpac_Q
'    ag33250a_SWEEP_SPAC_LIN
'    ag33250a_SWEEP_SPAC_LOG

' Used by Function ag33250a_sweStat
Global Const ag33250a_SWEEP_STAT_OFF = 0
Global Const ag33250a_SWEEP_STAT_ON = 1

' Used by Function ag33250a_sweTime
Global Const ag33250a_SWEEP_TIME_MAX = 500
Global Const ag33250a_SWEEP_TIME_MIN = 0.001

' Used by Function ag33250a_sweTime_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_trigSour
Global Const ag33250a_TRIGGER_SOUR_IMM = 0
Global Const ag33250a_TRIGGER_SOUR_EXT = 1
Global Const ag33250a_TRIGGER_SOUR_BUS = 2

' Used by Function ag33250a_trigSour_Q
'    ag33250a_TRIGGER_SOUR_IMM
'    ag33250a_TRIGGER_SOUR_EXT
'    ag33250a_TRIGGER_SOUR_BUS

' Used by Function ag33250a_volt
Global Const ag33250a_OUTPUT_VOLT_MAX = 10#
Global Const ag33250a_OUTPUT_VOLT_MIN = 0.001

' Used by Function ag33250a_voltAutRange
Global Const ag33250a_AUTO_RANGE_OFF = 0
Global Const ag33250a_AUTO_RANGE_ON = 1

' Used by Function ag33250a_voltHigh
Global Const ag33250a_OUTPUT_VOLT_HIGH_MAX = 5
Global Const ag33250a_OUTPUT_VOLT_HIGH_MIN = -5

' Used by Function ag33250a_voltHigh_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_voltLow
Global Const ag33250a_OUTPUT_VOLT_LOW_MAX = 5
Global Const ag33250a_OUTPUT_VOLT_LOW_MIN = -5

' Used by Function ag33250a_voltLow_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_voltOffs
Global Const ag33250a_OUTPUT_VOLT_OFFS_MAX = 5
Global Const ag33250a_OUTPUT_VOLT_OFFS_MIN = -5

' Used by Function ag33250a_voltOffs_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_voltUnit
Global Const ag33250a_OUTPUT_VOLT_UNIT_VPP = 0
Global Const ag33250a_OUTPUT_VOLT_UNIT_VRMS = 1
Global Const ag33250a_OUTPUT_VOLT_UNIT_DBM = 2
Global Const ag33250a_OUTPUT_VOLT_UNIT_DEF = 3

' Used by Function ag33250a_voltUnit_Q
'    ag33250a_OUTPUT_VOLT_UNIT_VPP
'    ag33250a_OUTPUT_VOLT_UNIT_VRMS
'    ag33250a_OUTPUT_VOLT_UNIT_DBM
'    ag33250a_OUTPUT_VOLT_UNIT_DEF

' Used by Function ag33250a_volt_Q
'    ag33250a_CURRENT_RANGE
'    ag33250a_MIN_RANGE
'    ag33250a_MAX_RANGE

' Used by Function ag33250a_sysInterface
Global Const ag33250a_SYS_INT_GPIB = 0
Global Const ag33250a_SYS_INT_RS232 = 1


'------------------------------------------------------------------------------
' Function Declarations
'------------------------------------------------------------------------------

Declare Function ag33250a_amDept Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal amDept As Double) As Long

Declare Function ag33250a_amDept_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pAmDept As Double) As Long

Declare Function ag33250a_amIntFreq Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal amIntFreq As Double) As Long

Declare Function ag33250a_amIntFreq_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pAmIntFreq As Double) As Long

Declare Function ag33250a_amIntFunc Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal amIntFunc As Integer) As Long

Declare Function ag33250a_amIntFunc_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pAmIntFunc As Integer) As Long

Declare Function ag33250a_amSour Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal amSour As Integer) As Long

Declare Function ag33250a_amSour_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pAmSour As Integer) As Long

Declare Function ag33250a_amState Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal amStat As Integer) As Long

Declare Function ag33250a_amState_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pAmStat As Integer) As Long

Declare Function ag33250a_appl Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal func As Integer, ByVal freq As Double, ByVal ampl As Double, ByVal offs As Double) As Long

Declare Function ag33250a_appl_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal Strng As String) As Long

Declare Function ag33250a_bmIntRate Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal bmIntRate As Double) As Long

Declare Function ag33250a_bmIntRate_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pBmIntRate As Double) As Long

Declare Function ag33250a_bmNcyc Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal bmNcyc As Long) As Long

Declare Function ag33250a_bmNcyc_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pBmNcyc As Long) As Long

Declare Function ag33250a_bmPhas Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal bmPhas As Integer) As Long

Declare Function ag33250a_bmPhas_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pBmPhas As Integer) As Long

Declare Function ag33250a_bmSour Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal bmSour As Integer) As Long

Declare Function ag33250a_bmSour_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pBmSour As Integer) As Long

Declare Function ag33250a_bmStat Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal bmStat As Integer) As Long

Declare Function ag33250a_bmStat_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pBmStat As Integer) As Long

Declare Function ag33250a_calCoun_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pCalCoun As Integer) As Long

Declare Function ag33250a_calSecCode Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal calSecCode As String) As Long

Declare Function ag33250a_calSecStat Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal state As Integer, ByVal calSecStat As String) As Long

Declare Function ag33250a_calSecStat_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pCalSecStat As Integer) As Long

Declare Function ag33250a_calSet Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal calSet As Integer) As Long

Declare Function ag33250a_calSet_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pCalSet As Integer) As Long

Declare Function ag33250a_calStr Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal calStr As String) As Long

Declare Function ag33250a_calStr_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal pCalStr As String) As Long

Declare Function ag33250a_calVal Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal calVal As String) As Long

Declare Function ag33250a_calVal_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal pCalVal As String) As Long

Declare Function ag33250a_cal_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pCal As Integer) As Long

Declare Function ag33250a_dataAttrAver_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pDataAttrAver As Double) As Long

Declare Function ag33250a_dataAttrCfac_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pDataAttrCfac As Double) As Long

Declare Function ag33250a_dataAttrPTPeak_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pDataAttrPTPeak As Double) As Long

Declare Function ag33250a_dataAttrPoin_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pDataAttrPoin As Double) As Long

Declare Function ag33250a_dataCat_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal pDataCat As String) As Long

Declare Function ag33250a_dataCopy Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal dataCopy As String) As Long

Declare Function ag33250a_dataDacVolatile Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal NoOfPoints As Long, DataArray As Integer) As Long

Declare Function ag33250a_dataDel Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal dataDel As String) As Long

Declare Function ag33250a_dataDelAll Lib "ag33250a_32.dll" (ByVal vi As Long) As Long

Declare Function ag33250a_dataNvolCat_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal pDataNvolCat As String) As Long

Declare Function ag33250a_dataNvolFree_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pDataNvolFree As Integer) As Long

Declare Function ag33250a_dataVolatile Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal NoOfPoints As Long, DataArray As Double) As Long

Declare Function ag33250a_disp Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal disp As Integer) As Long

Declare Function ag33250a_dispText Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal dispText As String) As Long

Declare Function ag33250a_dispTextCle Lib "ag33250a_32.dll" (ByVal vi As Long) As Long

Declare Function ag33250a_dispText_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal pDispText As String) As Long

Declare Function ag33250a_disp_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pDisp As Integer) As Long

Declare Function ag33250a_fmDev Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal fmDev As Double) As Long

Declare Function ag33250a_fmDev_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pFmDev As Double) As Long

Declare Function ag33250a_fmIntFreq Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal fmIntFreq As Double) As Long

Declare Function ag33250a_fmIntFreq_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pFmIntFreq As Double) As Long

Declare Function ag33250a_fmIntFunc Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal fmIntFunc As Integer) As Long

Declare Function ag33250a_fmIntFunc_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pfmIntFunc As Integer) As Long

Declare Function ag33250a_fmStat Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal fmStat As Integer) As Long

Declare Function ag33250a_fmStat_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pFmStat As Integer) As Long

Declare Function ag33250a_formBord Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal formBord As Integer) As Long

Declare Function ag33250a_formBord_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pFormBord As Integer) As Long

Declare Function ag33250a_freq Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal freq As Double) As Long

Declare Function ag33250a_freqStar Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal freqStar As Double) As Long

Declare Function ag33250a_freqStar_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pFreqStar As Double) As Long

Declare Function ag33250a_freqStop Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal freqStop As Double) As Long

Declare Function ag33250a_freqStop_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pFreqStop As Double) As Long

Declare Function ag33250a_freq_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pFreq As Double) As Long

Declare Function ag33250a_fskFreq Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal fskFreq As Double) As Long

Declare Function ag33250a_fskFreq_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pFskFreq As Double) As Long

Declare Function ag33250a_fskIntRate Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal fskIntRate As Double) As Long

Declare Function ag33250a_fskIntRate_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pFskIntRate As Double) As Long

Declare Function ag33250a_fskSour Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal fskSour As Integer) As Long

Declare Function ag33250a_fskSour_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pFskSour As Integer) As Long

Declare Function ag33250a_fskStat Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal fskStat As Integer) As Long

Declare Function ag33250a_fskStat_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pFskStat As Integer) As Long

Declare Function ag33250a_funcShap Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal funcShap As Integer) As Long

Declare Function ag33250a_funcShapUser Lib "ag33250a_32.dll" (ByVal vi As Long) As Long

Declare Function ag33250a_funcShap_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pFuncShap As Integer) As Long

Declare Function ag33250a_funcUser Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal funcUser As Integer) As Long

Declare Function ag33250a_funcUser_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pFuncUser As Integer) As Long

Declare Function ag33250a_funcUserName Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal funcUserName As String) As Long

Declare Function ag33250a_funcUser_NameQ Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal pFuncUserName As String) As Long

Declare Function ag33250a_memStatDel Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal memStatDel As Integer) As Long

Declare Function ag33250a_outpSetup Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal outpSetup As Integer) As Long

Declare Function ag33250a_outpSetup_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pOutpSetup As Integer) As Long

Declare Function ag33250a_outpLoad Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal outpLoad As Integer) As Long

Declare Function ag33250a_outpLoad_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pOutpLoad As Double) As Long

Declare Function ag33250a_outpSync Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal outpSync As Integer) As Long

Declare Function ag33250a_outpSync_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pOutpSync As Integer) As Long

Declare Function ag33250a_pulsDcyc Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal pulsDcyc As Double) As Long

Declare Function ag33250a_pulsDcyc_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pPulsDcyc As Double) As Long

Declare Function ag33250a_pulsePeriod Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal pulsePeriod As Double) As Long

Declare Function ag33250a_pulsePeriod_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pPulsePeriod As Double) As Long

Declare Function ag33250a_pulseWidth Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal pulseWidth As Double) As Long

Declare Function ag33250a_pulseWidth_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pPulseWidth As Double) As Long

Declare Function ag33250a_pulseTrans Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal pulseTrans As Double) As Long

Declare Function ag33250a_pulseTrans_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pPulseTrans As Double) As Long

Declare Function ag33250a_rampSymm Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal rampSymm As Double) As Long

Declare Function ag33250a_rampSymm_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pRampSymm As Double) As Long

Declare Function ag33250a_rcl Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal rcl As Integer) As Long

Declare Function ag33250a_sav Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal sav As Integer) As Long

Declare Function ag33250a_sweSpac Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal sweSpac As Integer) As Long

Declare Function ag33250a_sweSpac_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pSweSpac As Integer) As Long

Declare Function ag33250a_sweStat Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal sweStat As Integer) As Long

Declare Function ag33250a_sweStat_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pSweStat As Integer) As Long

Declare Function ag33250a_sweTime Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal sweTime As Double) As Long

Declare Function ag33250a_sweTime_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pSweTime As Double) As Long

Declare Function ag33250a_systBeep Lib "ag33250a_32.dll" (ByVal vi As Long) As Long

Declare Function ag33250a_systVer_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal systVer As String) As Long

Declare Function ag33250a_trigSour Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal trigSour As Integer) As Long

Declare Function ag33250a_trigSour_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pTrigSour As Integer) As Long

Declare Function ag33250a_volt Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal volt As Double) As Long

Declare Function ag33250a_voltAutRange Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal voltAutRange As Integer) As Long

Declare Function ag33250a_voltAutRange_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pVoltAutRange As Integer) As Long

Declare Function ag33250a_voltHigh Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal voltHigh As Double) As Long

Declare Function ag33250a_voltHigh_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pVoltHigh As Double) As Long

Declare Function ag33250a_voltLow Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal voltLow As Double) As Long

Declare Function ag33250a_voltLow_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pVoltLow As Double) As Long

Declare Function ag33250a_voltOffs Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal voltOffs As Double) As Long

Declare Function ag33250a_voltOffs_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pVoltOffs As Double) As Long

Declare Function ag33250a_voltUnit Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal voltUnit As Integer) As Long

Declare Function ag33250a_voltUnit_Q Lib "ag33250a_32.dll" (ByVal vi As Long, pVoltUnit As Integer) As Long

Declare Function ag33250a_volt_Q Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal range As Integer, pVolt As Double) As Long

Declare Function ag33250a_sysInterface Lib "ag33250a_32.dll" (ByVal vi As Long, ByVal sysInt As Integer) As Long

